"use client"
import { useAppSelector } from "@/lib/hooks";
import { useGetAttendanceRangeQuery, useGetMonthlyAttendanceQuery, useGetOrganizationAttendanceQuery } from "@/services/api";
import { ExclamationCircleIcon } from "@heroicons/react/24/outline";
import { BarChart, ChartsTooltip, LineChart, pieArcClasses, pieArcLabelClasses, PieChart } from "@mui/x-charts";
import { ChartsNoDataOverlay } from "@mui/x-charts/ChartsOverlay";
import { formatDate } from "date-fns";

export default function AbsensiPage() {
  const filter = useAppSelector(state => state.filter.filter);
  const {data: attendanceSummary} = useGetOrganizationAttendanceQuery(filter);
  const {data: attendanceRange} = useGetAttendanceRangeQuery(filter);
  const {data: montlyAttendance} = useGetMonthlyAttendanceQuery(filter);
  
  return (
    <div className="grid grid-cols-12 gap-4">
      <div className="col-span-4 bg-white py-4 px-4 rounded-lg max-h-[640px] flex flex-col">
        <div className="text-xl font-bold">Kehadiran Staff</div>
        <div className="flex-1 flex">
          {attendanceRange && <PieChart className="w-full" series={[
            {
              arcLabelMinAngle: 35,
              arcLabel: (v) => `${v.label} HK`,
              data: attendanceRange.map(e => ({label: e.range, value: e.count})),
              innerRadius: "50%",
              valueFormatter: (v) => v.value+" employees"
            },
          ]} colors={[
            "#E65550","#8A5FB1","#69C9C9","#F08431","#F6C421"
          ]}
          slotProps={{
            legend: {
              direction: "row",
              position: {vertical: "bottom", horizontal: "middle"}
            },
            pieArcLabel: {
              classes: {
                root: "text-white fill-current"
              }
            },
          }}
          sx={{
            [`& .${pieArcLabelClasses.root}`]: {
              color:"white",
              fontWeight: "bold"
            }}}
          margin={{top: 20, right: 20, bottom: 20, left: 20}}
          slots={{
            noDataOverlay: (props) => <ChartsNoDataOverlay {...props} message="Data belum tersedia" />
          }}
          />}
        </div>
      </div>
      <div className="col-span-4 bg-white rounded-lg py-4 pl-4 max-h-[640px] flex flex-col">
        <div className="text-xl font-bold">Kehadiran Non Staff</div>
        <div className="flex-1 min-h-[300px] flex justify-center items-center flex-col">
          <span className="text-gray-600">Data belum tersedia</span>
        </div>
      </div>
      <div className="col-span-4 max-h-[640px] flex flex-col gap-4">
        <div className="bg-white rounded-lg py-4 pl-4 flex flex-col">
            <div className="text-xl font-bold">Kehadiran Non Staff</div>
            <div className="flex-1 min-h-[253px] flex justify-center items-center flex-col">
                <span className="text-gray-600">Data belum tersedia</span>
            </div>
        </div>
        <div className="bg-white rounded-lg py-4 pl-4 flex flex-col">
            <div className="text-xl font-bold">Kehadiran Non Staff</div>
            <div className="flex-1 min-h-[253px] flex justify-center items-center flex-col">
                <span className="text-gray-600">Data belum tersedia</span>
            </div>
        </div>
      </div>
      <div className="col-span-8 bg-white py-4 pl-4 rounded-lg max-h-[420px] flex flex-col">
        <div className="text-xl font-bold">Data Kehadiran Karyawan Setiap Perusahaan</div>
        <div className="flex-1 min-h-[300px]">
        {attendanceSummary && <BarChart className="w-full"  dataset={attendanceSummary} series={[
            {dataKey: "count", label: (v) => v === "tooltip" ? "Attendance" : undefined!, color: "#2385DE", stack: "attendance", stackOffset: "expand", valueFormatter: (v) => v + " mandays"},
            {dataKey: "absent", label: (v) => v === "tooltip" ? "Absent" : undefined!, color: "#F7B500", stack: "attendance", stackOffset: "expand", valueFormatter: (v) => v + " mandays"},
        ]} xAxis={[
            {dataKey: "organization_code", label: "Nama Perusahaan", scaleType: "band", valueFormatter: (v, context) => context.location === "tooltip" ? attendanceSummary.find(e => e.organization_code === v)?.organization_name : v}
        ]}
        yAxis={[
          {dataKey: "count",scaleType: "linear", valueFormatter: (v) => (v*100)+"%"}
        ]}
        slots={{
          noDataOverlay: ()=> <ChartsNoDataOverlay message="Data belum tersedia" />,
        }}
        />}
        </div>
      </div>
      <div className="col-span-4 bg-white rounded-lg py-4 pl-4 max-h-[420px] flex flex-col">
        <div className="text-xl font-bold">Data Karyawan Perbulan</div>
        <div className="flex-1 min-h-[300px]">
          {montlyAttendance && <LineChart className="w-full" dataset={montlyAttendance} series={[
            {dataKey: "count", label: (v) => "Kehadiran" , area: false, color: "#F7CAA9"},
            {dataKey: "workdays", label: (v) => "Mandays", area: false, color: "#2385DE"},
          ]} xAxis={[
            {dataKey: "date", label: "Bulan", scaleType: "band", valueFormatter: (v, context) => formatDate(new Date(v), context.location === "tooltip" ? "MMMM yyyy" : "MMM")}
          ]} 
          />}
        </div>
      </div>
    </div>
  );
}