"use client"
import { useAppSelector } from "@/lib/hooks";
import { useDimensions } from "@/lib/hooks/dimension";
import { useGetResignCategoryQuery, useGetResignReasonQuery, useGetResignSummaryQuery, useGetResignTypeQuery } from "@/services/api";
import { BarChart, pieArcLabelClasses, PieChart } from "@mui/x-charts";
import { ChartsNoDataOverlay } from "@mui/x-charts/ChartsOverlay";
import { Loader, LucideLoader2 } from "lucide-react";
import React from "react";
import { useRef } from "react";
import { Tooltip } from "react-tooltip";

export default function TurnoverPage() {

    const filter = useAppSelector(state => state.filter.filter);
    const resignRef = useRef<HTMLDivElement>(null);
    const {width, height} = useDimensions(resignRef);
    const {data : resignSummary, isFetching: resignSummaryLoading} = useGetResignSummaryQuery(filter);
    const {data : resignType, isFetching: resignTypeLoading} = useGetResignTypeQuery(filter);
    const {data : resignCategory, isFetching: resignCategoryLoading} = useGetResignCategoryQuery(filter);
    const {data : resignReason, isFetching: resignReasonLoading} = useGetResignReasonQuery(filter);

    const [turnOverRatio, setTurnOverRatio] = React.useState(0);
    const [resign, setResign] = React.useState(0);
    const [active, setActive] = React.useState(0);

    const [maxResignType, setMaxResignType] = React.useState(0);

    React.useEffect(() => {
        if(resignSummary){
            const totalResign = resignSummary.reduce((acc, curr) => acc + curr.count, 0);
            const totalActive = resignSummary.reduce((acc, curr) => acc + curr.active, 0);
            setTurnOverRatio(Math.round(totalResign / totalActive * 100));
            setResign(totalResign);
            setActive(totalActive);
        }
    }, [resignSummary]);

    React.useEffect(() => {
        if(resignType){
            const max = resignType.reduce((acc, curr) => Math.max(acc, curr.count), 0);
            setMaxResignType(max);
        }
    }, [resignType]);

    const getColorByCategory = (category: string) => {
        switch(category){
            case "Whitelist":
                return "#EAEAEA";
            case "Blacklist":
                return "#3D3D3D";
            case "Yellowlist":
                return "#F5C41F";
            default:
                return undefined;
        }
    }

    return (
        <div className="grid grid-cols-12 gap-4">
            <div className="col-span-4 bg-white rounded-lg py-4 px-4 max-h-[420px] flex flex-col">
                <div className="text-lg font-bold">Karyawan Baru Seluruh Perusahaan</div>
                <div className="flex-1 min-h-[300px] flex justify-center items-center flex-col">
                    <span className="text-gray-600">Data belum tersedia</span>
                </div>
            </div>
            <div className="col-span-8 bg-white rounded-lg py-4 px-4 max-h-[420px] flex flex-col">
                <div className="text-lg font-bold">Man Power Planning per Perusahaan : Recruitment</div>
                <div className="flex-1 min-h-[300px] flex justify-center items-center flex-col">
                    <span className="text-gray-600">Data belum tersedia</span>
                </div>
            </div>
            <div className="col-span-4 bg-white rounded-lg py-4 px-4 max-h-[420px] flex flex-col">
                <div className="text-lg font-bold">Karyawan Resign Seluruh Perusahaan</div>
                <div className="relative h-24 bg-[#C7EBEB] mt-8 rounded-xl" ref={resignRef}>
                    <div className={`absolute top-0 left-0 h-24 bg-[#6AC8C8] rounded-xl transition-all duration-1000`} style={{width: `${width * turnOverRatio / 100}px`}}></div>
                </div>
                <div className="flex mt-6 justify-around gap-3">
                    <div className="px-3 py-4 flex-1 flex flex-col border border-[#DDE8F8] rounded-lg">
                        <div className="text-sm text-[#5A5A5A]">Rasio Turn Over</div>
                        <div className="text-xl font-bold">{turnOverRatio} %</div>
                    </div>
                    <div className="px-3 py-4 flex-1 flex flex-col border border-[#DDE8F8] rounded-lg">
                        <div className="text-sm text-[#5A5A5A]">Karyawan Resign</div>
                        <div className="text-xl font-bold">{resign}</div>
                    </div>
                    <div className="px-3 py-4 flex-1 flex flex-col border border-[#DDE8F8] rounded-lg">
                        <div className="text-sm text-[#5A5A5A]">Karyawan Aktif</div>
                        <div className="text-xl font-bold">{active}</div>
                    </div>
                </div>
            </div>
            <div className="col-span-8 bg-white py-4 pl-4 rounded-lg max-h-[420px] flex flex-col">
                <div className="text-xl font-bold">Resignment per Perusahaan : Jumlah Karyawan</div>
                <div className="flex-1 min-h-[300px] relative">
                {resignSummary && !resignSummaryLoading && <BarChart className="w-full"  dataset={resignSummary} series={[
                    {dataKey: "count", label: (v) => v === "tooltip" ? "Resign" : undefined!, color: "#F7B500", stack: "resign", stackOffset: "expand"},
                    {dataKey: "active", label: (v) => v === "tooltip" ? "Active" : undefined!, color: "#2385DE", stack: "resign", stackOffset: "expand"},
                ]} xAxis={[
                    {dataKey: "organization_code", label: "Nama Perusahaan", scaleType: "band", valueFormatter: (v, context) => context.location === "tooltip" ? resignSummary.find(e => e.organization_code === v)?.organization_name : v}
                ]}
                yAxis={[
                {dataKey: "count",scaleType: "linear", valueFormatter: (v) => (v*100)+"%"}
                ]}
                slots={{
                noDataOverlay: ()=> <ChartsNoDataOverlay message="Data belum tersedia" />,
                }}
                />}
                {resignSummaryLoading && <LucideLoader2 className="absolute top-1/2 left-1/2 animate-spin" />}
                </div>
            </div>
            <div className="col-span-4 bg-white py-4 px-4 rounded-lg max-h-[420px] flex flex-col">
                <div className="text-xl font-bold">Jenis Pemutusan Hubungan Kerja</div>
                <div className={`flex-1 min-h-[300px] gap-3 flex flex-col mt-8 ${resignType && resignType.length === 0 ? "justify-center items-center" : ""}`}>
                    {resignType && resignType.map((resign, index) => (
                        <div key={index} className="grid grid-cols-12 items-center"  data-tooltip-id="tooltip-tor-type" data-tooltip-content={`${resign.count} Employee`}>
                            <div className="text-sm col-span-3 text-gray-600">{resign.type}</div>
                            <div className="col-span-1"/>
                            <div className="relative col-span-8 h-6 bg-[#2385DE] rounded-lg">
                                <div className="absolute top-0 left-0 h-6 bg-[#F7B500] rounded-lg" style={{width: `${resign.count / maxResignType * 100}%`}}/>
                            </div>
                        </div>
                    ))}
                    {resignType && resignType.length === 0 && <span className="text-black text-sm text-center">Data belum tersedia</span>}
                    <Tooltip id="tooltip-tor-type" />
                </div>
            </div>
            <div className="col-span-4 bg-white py-4 px-4 rounded-lg max-h-[420px] flex flex-col">
                <div className="text-xl font-bold">Kategory Resign</div>
                <div className="w-4/5 flex-1 flex mx-auto">
                    {resignCategory && <PieChart className="" series={[
                        {
                            arcLabelMinAngle: 35,
                            arcLabel: (v) => `${v.label}`,
                            data: resignCategory.map(e => ({label: e.category, value: e.count, color: getColorByCategory(e.category)})),
                            valueFormatter: (v) => v.value+" employees",
                        },
                    ]}
                    slotProps={{
                        legend: {
                            direction: "row",
                            position: {vertical: "bottom", horizontal: "middle"}
                        },
                        pieArcLabel: {
                            classes: {
                                root: "hidden"
                            }
                        },
                    }}
                    sx={{
                        [`& .${pieArcLabelClasses.root}`]: {
                        color:"white",
                        fontWeight: "bold"
                        }}}
                    margin={{top: 20, right: 20, bottom: 60, left: 20}}
                    slots={{
                        noDataOverlay: (props) => <ChartsNoDataOverlay {...props} message="Data belum tersedia" />
                    }}
                    />}
                    </div>
            </div>
            <div className="col-span-4 bg-white py-4 px-4 rounded-lg max-h-[420px] flex flex-col">
                <div className="text-xl font-bold">Jenis Pemutusan Hubungan Kerja</div>
                <div className={`flex-1 min-h-[300px] gap-3 flex flex-col mt-8 ${resignReason && resignReason.length === 0 ? "justify-center items-center" : ""}`}>
                    {resignReason && resignReason.map((resign, index) => (
                        <div key={index} className="grid grid-cols-12 items-center" data-tooltip-id="tooltip-tor-type" data-tooltip-content={`${resign.count} Employee`}>
                            <div className="text-sm col-span-3 text-gray-600">{resign.reason}</div>
                            <div className="col-span-1"/>
                            <div className="relative col-span-8 h-6 bg-[#2385DE] rounded-lg">
                                <div className="absolute top-0 left-0 h-6 bg-[#F7B500] rounded-lg" style={{width: `${resign.count / maxResignType * 100}%`}}/>
                            </div>
                        </div>
                    ))}
                    {resignReason && resignReason.length === 0 && <span className="text-black text-sm text-center">Data belum tersedia</span>}
                    <Tooltip id="tooltip-tor-type" />
                </div>
            </div>
        </div>
    )
}