import { createApi, fetchBaseQuery } from '@reduxjs/toolkit/query/react'
import { AttendanceRange, AttendanceSummary, EmployeeSummary, FilterOptions, MonthlyAttendance, MonthlyEmployee, ResignationCategory, ResignationReason, ResignationType as ResignationType, ResignSummary } from './types'
import { Response , Filter} from './types'

export const api = createApi({
    baseQuery: fetchBaseQuery({ baseUrl: 'http://localhost:8080' }),
    endpoints: (builder) => ({
        getFilterOptions: builder.query<FilterOptions, Filter>({
            query: (params) => ({ url: '/dashboard/filter-options', params }),
            transformResponse: (response: Response) => {
                if (response.status === "success") {
                    return response.data!;
                }
            },
        }),
        getEmployeeSummary: builder.query<EmployeeSummary[], Filter>({
            query: (params) => ({ url: '/dashboard/employee', params }),
            transformResponse: (response: Response) => {
                if (response.status === "success") {
                    return response.data!;
                }
            },
        }),
        getMonthlyEmployee: builder.query<MonthlyEmployee[], Filter>({
            query: (params) => ({ url: '/dashboard/monthly-employee', params }),
            transformResponse: (response: Response) => {
                if (response.status === "success") {
                    return response.data!;
                }
            },
        }),
        getOrganizationAttendance: builder.query<AttendanceSummary[], Filter>({
            query: (params) => ({ url: '/dashboard/organization-attendance', params }),
            transformResponse: (response: Response) => {
                if (response.status === "success") {
                    return response.data!;
                }
            },
        }),
        getAttendanceRange: builder.query<AttendanceRange[], Filter>({
            query: (params) => ({ url: '/dashboard/attendance-range', params }),
            transformResponse: (response: Response) => {
                if (response.status === "success") {
                    return response.data!;
                }
            },
        }),
        getMonthlyAttendance: builder.query<MonthlyAttendance[], Filter>({
            query: (params) => ({ url: '/dashboard/monthly-attendance', params }),
            transformResponse: (response: Response) => {
                if (response.status === "success") {
                    return response.data!;
                }
            },
        }),
        getResignSummary: builder.query<ResignSummary[], Filter>({
            query: (params) => ({ url: '/dashboard/to-resign', params }),
            transformResponse: (response: Response) => {
                if (response.status === "success") {
                    return response.data!;
                }
            },
        }),
        getResignType: builder.query<ResignationType[], Filter>({
            query: (params) => ({ url: '/dashboard/to-resign-type', params }),
            transformResponse: (response: Response) => {
                if (response.status === "success") {
                    return response.data!;
                }
            },
        }),
        getResignCategory: builder.query<ResignationCategory[], Filter>({
            query: (params) => ({ url: '/dashboard/to-resign-category', params }),
            transformResponse: (response: Response) => {
                if (response.status === "success") {
                    return response.data!;
                }
            },
        }),
        getResignReason: builder.query<ResignationReason[], Filter>({
            query: (params) => ({ url: '/dashboard/to-resign-reason', params }),
            transformResponse: (response: Response) => {
                if (response.status === "success") {
                    return response.data!;
                }
            },
        }),
    }),
})

export const { useGetFilterOptionsQuery, useGetEmployeeSummaryQuery, useGetMonthlyEmployeeQuery, useGetMonthlyAttendanceQuery,
    useGetOrganizationAttendanceQuery, useGetAttendanceRangeQuery, useGetResignSummaryQuery, useGetResignTypeQuery,
     useGetResignCategoryQuery, useGetResignReasonQuery } = api