export interface ApiResult<T> {
    data: T;
    message: string;
    status: string;
}

export type ErrorResponse = ApiResult<null>;
export type Response = ApiResult<any>;

export function isErrorResponse(response: any): response is ErrorResponse {
    return response.status === "error";
}

export interface Filter{
    start_date?: string;
    end_date?: string;
    organization_code?: string;
    estate_name?: string;
    job_name?: string;
}

export interface FilterOptions{
    regions: {
        name: string;
        codes: string;
    }[];
    organizations: {
        code: string;
        name: string;
    }[];
    estates: {
        name: string;
    }[];
}

export type EmployeeSummary = {
    id: string;
    organization_code: string;
    organization_name: string;
    count: number;
    updated_at: string;
    created_at: string;
}

export type AttendanceSummary = {
    organization_code: string;
    organization_name: string;
    workdays: number;
    absent: number;
    count: number;
}

export type MonthlyEmployee = {
    date: string;
    count: number;
}

export type MonthlyAttendance = {
    date: string;
    workdays: number;
    count: number;
}

export type AttendanceRange = {
    range: string;
    count: number;
}

export type ResignSummary = {
    organization_code: string;
    organization_name: string;
    count: number;
    active: number;
}

export type ResignationType = {
    type: string;
    count: number;
}

export type ResignationCategory = {
    category: string;
    count: number;
}

export type ResignationReason = {
    reason: string;
    count: number;
}